.. image:: https://travis-ci.org/GeoscienceAustralia/anuga_core.svg?branch=master
    :target: https://travis-ci.org/GeoscienceAustralia/anuga_core
    
.. image:: https://coveralls.io/repos/GeoscienceAustralia/anuga_core/badge.svg?branch=master
  :target: https://coveralls.io/r/GeoscienceAustralia/anuga_core?branch=master

.. image:: https://pypip.in/version/anuga/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/anuga/
    :alt: Latest Version
    
.. image:: https://pypip.in/download/anuga/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/anuga/
    :alt: Downloads
    
=====
AnuGA
=====

.. contents::

What is AnuGA?
--------------

AnuGA (pronounced "AHnooGAH") is open-source software for the simulation of
the shallow water equation, in particular it can be used to model tsunamis
and floods.

AnuGA is a python package with some C extensions (and an optional 
fortran extension). At present AnuGA has not been ported to python 3. 
We recommend using python 2.7  

Developed at Geoscience Australia and Mathematical Sciences Institute at the
Australian National University.

Copyright 2004 - 2015 
Ole Nielsen, Stephen Roberts, Duncan Gray, Jane Sexton, Gareth Davies


Installation
------------

For installation instructions, see 
`INSTALL.rst <https://github.com/GeoscienceAustralia/anuga_core/blob/master/INSTALL.rst>`_


Documentation
-------------

AnuGA documentation is available in the doc folder. In particular the 
`user_manual <https://github.com/GeoscienceAustralia/anuga_core/raw/master/doc/anuga_user_manual.pdf>`_

Also helpful information is available noline at

    http://anuga.anu.edu.au


Web sites
---------

The user's site is:

    http://anuga.anu.edu.au/


Mailing Lists
-------------

Please see anuga user mailing list here:

    anuga-user@lists.sourceforge.net


Latest source code
------------------

The latest development version of AnuGA's sources are is available at:

    https://github.com/GeoscienceAustralia/anuga_core

They can be downloaded as a zip file or using the Git client.


Bug reports
-----------

To search for bugs or report them, please use the AnuGA's Bug Tracker at:

    https://github.com/GeoscienceAustralia/anuga_core/issues


Developer information
---------------------

If you would like to take part in AnuGA development, take a look
at `CONTRIBUTING.rst <https://github.com/GeoscienceAustralia/anuga_core/blob/master/CONTRIBUTING.rst>`_.


License information
-------------------

See the file `LICENSE.txt <https://github.com/GeoscienceAustralia/anuga_core/blob/master/LICENCE.txt>`_ 
for information on the history of this software, terms & conditions for usage, 
and a DISCLAIMER OF ALL WARRANTIES.



